@@ -1,8 +1,10 @@
 /* json-types-private.h - JSON data types private header
  * 
  * This file is part of JSON-GLib
- * Copyright (C) 2007  OpenedHand Ltd
- * Copyright (C) 2009  Intel Corp.
+ *
+ * SPDX-FileCopyrightText: 2007  OpenedHand Ltd
+ * SPDX-FileCopyrightText: 2009  Intel Corp.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -21,8 +23,7 @@
  *   Emmanuele Bassi  <ebassi@linux.intel.com>
  */
 
-#ifndef __JSON_TYPES_PRIVATE_H__
-#define __JSON_TYPES_PRIVATE_H__
+#pragma once
 
 #include "json-types.h"
 
@@ -50,7 +51,8 @@ struct _JsonNode
   /*< private >*/
   JsonNodeType type;
 
-  volatile gint ref_count;
+  gatomicrefcount ref_count;
+
   gboolean immutable : 1;
   gboolean allocated : 1;
 
@@ -78,7 +80,7 @@ struct _JsonValue
 {
   JsonValueType type;
 
-  volatile gint ref_count;
+  grefcount ref_count;
   gboolean immutable : 1;
 
   union {
@@ -93,8 +95,9 @@ struct _JsonArray
 {
   GPtrArray *elements;
 
+  grefcount ref_count;
+
   guint immutable_hash;  /* valid iff immutable */
-  volatile gint ref_count;
   gboolean immutable : 1;
 };
 
@@ -102,11 +105,12 @@ struct _JsonObject
 {
   GHashTable *members;
 
+  grefcount ref_count;
+
   GQueue members_ordered;
 
   int age;
   guint immutable_hash;  /* valid iff immutable */
-  volatile gint ref_count;
   gboolean immutable : 1;
 };
 
@@ -184,5 +188,3 @@ G_GNUC_INTERNAL
 guint           json_value_hash                 (gconstpointer    key);
 
 G_END_DECLS
-
-#endif /* __JSON_TYPES_PRIVATE_H__ */
